/**
 * List of view modes
 *
 * @constant
 * @type {Object}
 */
var ViewMode = {
	EDIT: "edit",
	VIEW: "view",
	LIST: "list",
	INLINE_EDIT: "inline_edit"
};

/**
 * Creates an instance of a Modeable object
 *
 * @class
 * @name Modeable
 */
var Modeable = function() {

	/**
	 * Retrieve object mode
	 *
	 * @function getMode
	 * @memberOf Modeable
	 * @instance
	 * @returns {String} Object mode
	 */
	this.getMode = function() {
		return this.mode;
	};

	/**
	 * Restore object to default mode
	 *
	 * @function restoreDefaultMode
	 * @memberOf Modeable
	 * @instance
	 */
	this.restoreDefaultMode = function() {
		this.mode = ViewMode.LIST;
	};

	/**
	 * Update object mode
	 *
	 * @function changeMode
	 * @memberOf Modeable
	 * @instance
	 * @param  {String} mode - Object mode
	 */
	this.changeMode = function(mode) {
		this.mode = mode;
	};

	/**
	 * Check if object is in edit mode
	 *
	 * @function inEditMode
	 * @memberOf Modeable
	 * @instance
	 * @returns {Boolean} True if object is in edit mode
	 */
	this.inEditMode = function() {
		return this.mode === ViewMode.EDIT;
	};

	/**
	 * Check if object is in inline edit mode
	 *
	 * @function inInlineEditMode
	 * @memberOf Modeable
	 * @instance
	 * @returns {Boolean} True if object is in inline edit mode
	 */
	this.inInlineEditMode = function() {
		return this.mode === ViewMode.INLINE_EDIT;
	};

	/**
	 * Check if object is in view mode
	 *
	 * @function inViewMode
	 * @memberOf Modeable
	 * @instance
	 * @returns {Boolean} True if object is in view mode
	 */
	this.inViewMode = function() {
		return this.mode === ViewMode.VIEW;
	};

	/**
	 * Check if object is in list mode
	 *
	 * @function inListMode
	 * @memberOf Modeable
	 * @instance
	 * @returns {Boolean} True if object is in list mode
	 */
	this.inListMode = function() {
		return this.mode === ViewMode.LIST;
	};
};
